@@ -870,7 +870,7 @@ SESSION_COOKIE_AGE = 24 * 60 * 60
 # Days of remembered login info (deafult: 7 days)
 LOGIN_REMEMBER_DAYS = 7
 
-SEAFILE_VERSION = '13.0.15'
+SEAFILE_VERSION = '13.0.16'
 
 CAPTCHA_IMAGE_SIZE = (90, 42)
 
@@ -1085,6 +1085,7 @@ METADATA_FILE_TYPES = {
 #         seafile ai         #
 ##############################
 ENABLE_SEAFILE_AI = False
+ENABLE_FACE_RECOGNITION = False
 
 SEAFILE_AI_SERVER_URL = ''
 SEAFILE_AI_SECRET_KEY = ''
@@ -1309,6 +1310,10 @@ if os.environ.get('ENABLE_SEAFILE_AI'):
 SEAFILE_AI_SECRET_KEY = os.environ.get('SEAFILE_AI_SECRET_KEY', '') or SEAFILE_AI_SECRET_KEY
 SEAFILE_AI_SERVER_URL = os.environ.get('SEAFILE_AI_SERVER_URL', '') or SEAFILE_AI_SERVER_URL
 
+if os.environ.get('ENABLE_FACE_RECOGNITION'):
+    ENABLE_FACE_RECOGNITION = os.environ.get('ENABLE_FACE_RECOGNITION', 'false').lower() == 'true'
+
+ENABLE_FACE_RECOGNITION = ENABLE_METADATA_MANAGEMENT and ENABLE_SEAFILE_AI and ENABLE_FACE_RECOGNITION
 
 SEAFEVENTS_SERVER_URL = 'http://127.0.0.1:8889'
 
